@@ -24,6 +24,9 @@
 #include "command.h"
 #include "timeout.h"
 
+// remember to change the "AvrUsb500-X.X terminal mode" version string towards the end
+// of the program at version change.
+
 #define CONFIG_PARAM_BUILD_NUMBER_LOW   0
 #define CONFIG_PARAM_BUILD_NUMBER_HIGH  1
 // be careful with changing HW versions. avrstudio does not like all numbers:
@@ -53,7 +56,7 @@ const char terminal_init[] PROGMEM = {"\x1B[0m\x1B[2J\x1B[0;0f"};
 #define MSG_WAIT_CKSUM 6
 
 static unsigned char msg_buf[295];
-static unsigned char param_reset_polarity=0;
+static unsigned char param_reset_polarity=1; // 1=avr (reset active=low), 0=at89 (not supported by this avrusb500)
 static unsigned char param_controller_init=0;
 unsigned long address=0;
 unsigned long saddress=0;
@@ -157,7 +160,7 @@ void programcmd(unsigned char seqnum)
                         case PARAM_SCK_DURATION:
                                 tmp = spi_get_sck_duration();
                                 break;
-                        case PARAM_RESET_POLARITY:
+                        case PARAM_RESET_POLARITY:   // is actually write only, list anyhow
                                 tmp = param_reset_polarity;
                                 break;
                         case PARAM_CONTROLLER_INIT:
@@ -169,6 +172,12 @@ void programcmd(unsigned char seqnum)
                         case PARAM_OSC_CMATCH:
                                 tmp = CONFIG_PARAM_OSC_CMATCH;
                                 break;
+                        case PARAM_TOPCARD_DETECT: // stk500 only
+                                tmp = 0; // no card ??
+                                break;
+                        case PARAM_DATA: // stk500 only
+                                tmp = 0; 
+                                break;
                         default: 
                                 break;
                 }
@@ -176,7 +185,7 @@ void programcmd(unsigned char seqnum)
                         // command not understood
                         answerlen = 2;
                         //msg_buf[0] = CMD_GET_PARAMETER;
-                        msg_buf[1] = STATUS_CMD_FAILED;
+                        msg_buf[1] = STATUS_CMD_UNKNOWN;
                 }else{
                         answerlen = 3;
                         //msg_buf[0] = CMD_GET_PARAMETER;
@@ -602,12 +611,12 @@ void programcmd(unsigned char seqnum)
 
 // Read a max of 2 digits from the serial line
 // return value of -1 means no change (user just hit return)
-signed char terminalmode_readnum(unsigned char iswin){
+signed char terminalmode_readnum(unsigned char chr_nl){
         unsigned char ch;
         unsigned char lineendcnt=1;
         unsigned char digits=2; // you can enter max 2 digits
         signed char rval=-1;
-	if (iswin){
+	if (chr_nl){
 		// we expect \r\n as line end
 		lineendcnt=2;
 	}
@@ -641,18 +650,18 @@ void terminalmode_next_line(void)
         uart_sendchar('E');
 }
 
-void terminalmode(unsigned char iswin)
+void terminalmode(unsigned char chr_nl)
 {
 	signed char i;
 	// Init terminal
 	uart_sendstr_p(terminal_init);
 	//
-	uart_sendstr_P("AvrUsb500 terminal mode\r\n");
+	uart_sendstr_P("AvrUsb500-1.3 terminal mode\r\n");
 	uart_sendstr_P("Enter SW Version Major [");
 	utoa(CONFIG_PARAM_SW_MAJOR,(char *)msg_buf, 10);
 	uart_sendstr((char *)msg_buf);
 	uart_sendstr_P("]: ");
-	i=terminalmode_readnum(iswin);
+	i=terminalmode_readnum(chr_nl);
 	if (i >=0){
 		CONFIG_PARAM_SW_MAJOR=(unsigned char)i;
 	}
@@ -661,7 +670,7 @@ void terminalmode(unsigned char iswin)
 	utoa(CONFIG_PARAM_SW_MINOR,(char *)msg_buf, 10);
 	uart_sendstr((char *)msg_buf);
 	uart_sendstr_P("]: ");
-	i=terminalmode_readnum(iswin);
+	i=terminalmode_readnum(chr_nl);
 	if (i >=0){
 		CONFIG_PARAM_SW_MINOR=(unsigned char)i;
 	}
@@ -686,7 +695,7 @@ int main(void)
 {
         unsigned char ch;
         unsigned char prev_ch=0;
-        unsigned char iswin=0;
+        unsigned char chr_nl=0;
         unsigned char msgparsestate;
         unsigned char cksum=0;
         unsigned char seqnum=0;
@@ -714,16 +723,20 @@ int main(void)
                         cksum = ch^0;
                         continue;
                 }
-		// the special avrusb500 terminal mode.
-		// just connect a serial terminal and press enter twice.
+		// The special avrusb500 terminal mode.
+		// Just connect a serial terminal and press enter twice.
+		// Both Windows and Linux send normally \r (=0xd) as the
+		// only line end character. It is however possible to configure
+		// \r\n as line end in some serial terminals. Therefore we
+		// must handle it.
                 if (msgparsestate==MSG_IDLE && (ch == '\r'||ch == '\n')){
 			i++;
-			if(iswin ==0 && ch=='\n' && prev_ch== '\r'){
+			if(chr_nl ==0 && ch=='\n' && prev_ch== '\r'){
 				// terminal sends \r\n for new line
-				iswin=1;
+				chr_nl=1;
 			}
 			prev_ch=ch;
-			if (iswin){
+			if (chr_nl){
 				// wait for \r\n \r\n
 				if (i==4){
 					terminalmode(1);
