@@ -53,7 +53,7 @@ unsigned char  spi_set_sck_duration(unsigned char dur)
                 sck_dur=0;
                 return(sck_dur);
         }
-        return(1); // we should never come here
+        return(2); // we should never come here
 }
 
 unsigned char spi_get_sck_duration(void)
@@ -68,16 +68,22 @@ void spi_init(void)
         //
         sbi(DDRB,PB3); // MOSI is output
         sbi(DDRB,PB5); // SCK is output
+	// now output pins low in case somebody used it as output in his/her circuit
+        cbi(PORTB,PB3); // MOSI low
+        cbi(PORTB,PB5); // SCK low
+	//
         cbi(DDRB,PB4); // MISO is input
         //
         sbi(DDRB,PB2); // pb2 as reset pin is output
         sbi(PORTB,PB2); // reset = high = not active
-        delay_ms(2);
-        /* Enable SPI, Master, set clock rate fck/64 */
-        SPCR = (1<<SPE)|(1<<MSTR)|(1<<SPR1);
+        delay_ms(25); // discharge MOSI/SCK
+        /* Enable SPI, Master, set clock rate fck/16 */
+        SPCR = (1<<SPE)|(1<<MSTR)|(1<<SPR0);
         //
         cbi(PORTB,PB2); // reset = low, stay active
-        delay_ms(2);
+        cbi(PORTB,PB3); // MOSI low
+        cbi(PORTB,PB5); // SCK low
+        delay_ms(25); // minimum stab.-delay
         spi_set_sck_duration(sck_dur);
 }
 
