@@ -21,7 +21,7 @@ void delay_ms(unsigned int ms)
         // accurate and not so much compiler dependent
         // as self made code.
         while(ms){
-                _delay_loop_2(240.0);
+                _delay_ms(0.96);
                 ms--;
         }
 }
